epistasis\.simulate package
===========================


epistasis\.simulate\.base module
--------------------------------

.. automodule:: epistasis.simulate.base
    :members:
    :undoc-members:
    :show-inheritance:

epistasis\.simulate\.linear module
----------------------------------

.. automodule:: epistasis.simulate.linear
    :members:
    :undoc-members:
    :show-inheritance:

epistasis\.simulate\.power module
---------------------------------

.. automodule:: epistasis.simulate.power
    :members:
    :undoc-members:
    :show-inheritance:
